#include <vtkPlane.h>
#include <vtkCutter.h>
#include <vtkRTAnalyticSource.h>
#include <vtkSmartPointer.h>
#include <vtkXMLUnstructuredGridWriter.h>

#include "vtkCleanUnstructuredGrid.h"

int main(int, char *[])
{
  vtkSmartPointer<vtkRTAnalyticSource> analyticSource =
    vtkSmartPointer<vtkRTAnalyticSource>::New();
  analyticSource->SetWholeExtent(-10,10, -10,10, -10,10);

  // Create a plane to cut,here it cuts in the XZ direction (xz normal=(1,0,0);XY =(0,0,1),YZ =(0,1,0)
  vtkSmartPointer<vtkPlane> plane =
    vtkSmartPointer<vtkPlane>::New();
  plane->SetOrigin(0,0,0);
  plane->SetNormal(1,0,0);
  
  // Create cutter
  vtkSmartPointer<vtkCutter> cutter =
    vtkSmartPointer<vtkCutter>::New();
  cutter->SetCutFunction(plane);
  cutter->GenerateTrianglesOff();
  cutter->SetInputConnection(analyticSource->GetOutputPort());

  // Convert polyData to unstructuredGrid
  vtkSmartPointer<vtkCleanUnstructuredGrid> cleaner =
    vtkSmartPointer<vtkCleanUnstructuredGrid>::New();
  cleaner->SetInputConnection(cutter->GetOutputPort());
  cleaner->Update();
  
  // Write file
  vtkSmartPointer<vtkXMLUnstructuredGridWriter> writer =
    vtkSmartPointer<vtkXMLUnstructuredGridWriter>::New();
  writer->SetFileName("unstructuredGrid.vtu");
  writer->SetInputConnection(cleaner->GetOutputPort());
  writer->Write();
  
  return EXIT_SUCCESS;
}
